#!/bin/bash
#
# DOCUMENT:  Creates images and html
# VERSION:   $Revision: 1.9 $
# DATE:      $Date: 2007-09-02 21:20:58 $
# AUTHOR:    M.Beranek <marcus@beranek.de>
# COPYRIGHT: M.Beranek, http://www.beranek.de
# 
# This program is FREE SOFTWARE and may be copied and distributed
# as you like, as long as the above COPYRIGHT-notice stays untouched!
# 
# NOTE: Use at your own risk! 
#
# The author may not be held responsible for any damage to you or 
# your system caused by this program directly or indirectly.
# 
# You are allowed to modify this file, as long as you mark any
# modifications you have made.
#  

# TODO: graphs for a week, month and a year.

# Base-directory:
BASEDIR=`dirname $0`

# Load config:
. ${BASEDIR}/monitor_config.sh


# LAST 5 HOURS
# ----------------------------------------------------------
${RRD} graph ${OUTPUTDIR}/${IMAGE_HOUR_PROC} \
--start -18000 \
--vertical-label "processes" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:r=${LOGDIR}/${RRDFILE}:run:AVERAGE \
DEF:b=${LOGDIR}/${RRDFILE}:block:AVERAGE \
DEF:w=${LOGDIR}/${RRDFILE}:wait:AVERAGE \
AREA:r#EACC00:"Runnable" \
STACK:b#9C0000:"Blocked" \
STACK:w#3377DD:"Waiting"


${RRD} graph ${OUTPUTDIR}/${IMAGE_HOUR_MEM} \
--start -18000 \
--vertical-label "memory" \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:s=${LOGDIR}/${RRDFILE}:swpd:AVERAGE \
DEF:f=${LOGDIR}/${RRDFILE}:free:AVERAGE \
DEF:b=${LOGDIR}/${RRDFILE}:buff:AVERAGE \
DEF:c=${LOGDIR}/${RRDFILE}:cache:AVERAGE \
CDEF:sm=s,1024,* \
CDEF:fm=f,1024,* \
CDEF:bm=b,1024,* \
CDEF:cm=c,1024,* \
AREA:sm#9C0000:"Swapped" \
STACK:cm#EACC00:"Cached" \
STACK:bm#3377DD:"Buffered" \
STACK:fm#00FF00:"Free"


${RRD} graph ${OUTPUTDIR}/${IMAGE_HOUR_SWAP} \
--start -18000 \
--vertical-label "swap" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:si=${LOGDIR}/${RRDFILE}:si:AVERAGE \
DEF:so=${LOGDIR}/${RRDFILE}:so:AVERAGE \
AREA:si#9C0000:"Swap-In" \
STACK:so#EACC00:"Swap-Out" 


${RRD} graph ${OUTPUTDIR}/${IMAGE_HOUR_IO} \
--start -18000 \
--vertical-label "io-system" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:bi=${LOGDIR}/${RRDFILE}:bi:AVERAGE \
DEF:bo=${LOGDIR}/${RRDFILE}:bo:AVERAGE \
AREA:bi#9C0000:"Blocks-In" \
STACK:bo#EACC00:"Blocks-Out" 


${RRD} graph ${OUTPUTDIR}/${IMAGE_HOUR_SYS} \
--start -18000 \
--vertical-label "system" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:int=${LOGDIR}/${RRDFILE}:int:AVERAGE \
DEF:cont=${LOGDIR}/${RRDFILE}:cont:AVERAGE \
AREA:cont#EACC00:"Context-Switches" \
LINE1:int#9C0000:"Interrupts"


${RRD} graph ${OUTPUTDIR}/${IMAGE_HOUR_CPU} \
--start -18000 \
--vertical-label "cpu in %" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:user=${LOGDIR}/${RRDFILE}:user:AVERAGE \
DEF:sys=${LOGDIR}/${RRDFILE}:sys:AVERAGE \
DEF:idle=${LOGDIR}/${RRDFILE}:idle:AVERAGE \
AREA:user#EACC00:"User" \
STACK:sys#3377DD:"System" \
STACK:idle#00FF00:"Idle"


# TODAY
# ----------------------------------------------------------
${RRD} graph ${OUTPUTDIR}/${IMAGE_PROC} \
--start -86400 \
--vertical-label "processes" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:r=${LOGDIR}/${RRDFILE}:run:AVERAGE \
DEF:b=${LOGDIR}/${RRDFILE}:block:AVERAGE \
DEF:w=${LOGDIR}/${RRDFILE}:wait:AVERAGE \
AREA:r#EACC00:"Runnable" \
STACK:b#9C0000:"Blocked" \
STACK:w#3377DD:"Waiting"


${RRD} graph ${OUTPUTDIR}/${IMAGE_MEM} \
--start -86400 \
--vertical-label "memory" \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:s=${LOGDIR}/${RRDFILE}:swpd:AVERAGE \
DEF:f=${LOGDIR}/${RRDFILE}:free:AVERAGE \
DEF:b=${LOGDIR}/${RRDFILE}:buff:AVERAGE \
DEF:c=${LOGDIR}/${RRDFILE}:cache:AVERAGE \
CDEF:sm=s,1024,* \
CDEF:fm=f,1024,* \
CDEF:bm=b,1024,* \
CDEF:cm=c,1024,* \
AREA:sm#9C0000:"Swapped" \
STACK:cm#EACC00:"Cached" \
STACK:bm#3377DD:"Buffered" \
STACK:fm#00FF00:"Free"


${RRD} graph ${OUTPUTDIR}/${IMAGE_SWAP} \
--start -86400 \
--vertical-label "swap" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:si=${LOGDIR}/${RRDFILE}:si:AVERAGE \
DEF:so=${LOGDIR}/${RRDFILE}:so:AVERAGE \
AREA:si#9C0000:"Swap-In" \
STACK:so#EACC00:"Swap-Out" 


${RRD} graph ${OUTPUTDIR}/${IMAGE_IO} \
--start -86400 \
--vertical-label "io-system" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:bi=${LOGDIR}/${RRDFILE}:bi:AVERAGE \
DEF:bo=${LOGDIR}/${RRDFILE}:bo:AVERAGE \
AREA:bi#9C0000:"Blocks-In" \
STACK:bo#EACC00:"Blocks-Out" 


${RRD} graph ${OUTPUTDIR}/${IMAGE_SYS} \
--start -86400 \
--vertical-label "system" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:int=${LOGDIR}/${RRDFILE}:int:AVERAGE \
DEF:cont=${LOGDIR}/${RRDFILE}:cont:AVERAGE \
AREA:cont#EACC00:"Context-Switches" \
LINE1:int#9C0000:"Interrupts"


${RRD} graph ${OUTPUTDIR}/${IMAGE_CPU} \
--start -86400 \
--vertical-label "cpu in %" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:user=${LOGDIR}/${RRDFILE}:user:AVERAGE \
DEF:sys=${LOGDIR}/${RRDFILE}:sys:AVERAGE \
DEF:idle=${LOGDIR}/${RRDFILE}:idle:AVERAGE \
AREA:user#EACC00:"User" \
STACK:sys#3377DD:"System" \
STACK:idle#00FF00:"Idle"



# WEEK
# ----------------------------------------------------------
${RRD} graph ${OUTPUTDIR}/${IMAGE_WEEK_PROC} \
--start -604800 \
--vertical-label "processes" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:r=${LOGDIR}/${RRDFILE}:run:AVERAGE \
DEF:b=${LOGDIR}/${RRDFILE}:block:AVERAGE \
DEF:w=${LOGDIR}/${RRDFILE}:wait:AVERAGE \
AREA:r#EACC00:"Runnable" \
STACK:b#9C0000:"Blocked" \
STACK:w#3377DD:"Waiting"


${RRD} graph ${OUTPUTDIR}/${IMAGE_WEEK_MEM} \
--start -604800 \
--vertical-label "memory" \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:s=${LOGDIR}/${RRDFILE}:swpd:AVERAGE \
DEF:f=${LOGDIR}/${RRDFILE}:free:AVERAGE \
DEF:b=${LOGDIR}/${RRDFILE}:buff:AVERAGE \
DEF:c=${LOGDIR}/${RRDFILE}:cache:AVERAGE \
CDEF:sm=s,1024,* \
CDEF:fm=f,1024,* \
CDEF:bm=b,1024,* \
CDEF:cm=c,1024,* \
AREA:sm#9C0000:"Swapped" \
STACK:cm#EACC00:"Cached" \
STACK:bm#3377DD:"Buffered" \
STACK:fm#00FF00:"Free"


${RRD} graph ${OUTPUTDIR}/${IMAGE_WEEK_SWAP} \
--start -604800 \
--vertical-label "swap" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:si=${LOGDIR}/${RRDFILE}:si:AVERAGE \
DEF:so=${LOGDIR}/${RRDFILE}:so:AVERAGE \
AREA:si#9C0000:"Swap-In" \
STACK:so#EACC00:"Swap-Out" 


${RRD} graph ${OUTPUTDIR}/${IMAGE_WEEK_IO} \
--start -604800 \
--vertical-label "io-system" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:bi=${LOGDIR}/${RRDFILE}:bi:AVERAGE \
DEF:bo=${LOGDIR}/${RRDFILE}:bo:AVERAGE \
AREA:bi#9C0000:"Blocks-In" \
STACK:bo#EACC00:"Blocks-Out" 


${RRD} graph ${OUTPUTDIR}/${IMAGE_WEEK_SYS} \
--start -604800 \
--vertical-label "system" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:int=${LOGDIR}/${RRDFILE}:int:AVERAGE \
DEF:cont=${LOGDIR}/${RRDFILE}:cont:AVERAGE \
AREA:cont#EACC00:"Context-Switches" \
LINE1:int#9C0000:"Interrupts"


${RRD} graph ${OUTPUTDIR}/${IMAGE_WEEK_CPU} \
--start -604800 \
--vertical-label "cpu in %" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:user=${LOGDIR}/${RRDFILE}:user:AVERAGE \
DEF:sys=${LOGDIR}/${RRDFILE}:sys:AVERAGE \
DEF:idle=${LOGDIR}/${RRDFILE}:idle:AVERAGE \
AREA:user#EACC00:"User" \
STACK:sys#3377DD:"System" \
STACK:idle#00FF00:"Idle"


# MONTH
# ----------------------------------------------------------
${RRD} graph ${OUTPUTDIR}/${IMAGE_MONTH_PROC} \
--start -2678400 \
--vertical-label "processes" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:r=${LOGDIR}/${RRDFILE}:run:AVERAGE \
DEF:b=${LOGDIR}/${RRDFILE}:block:AVERAGE \
DEF:w=${LOGDIR}/${RRDFILE}:wait:AVERAGE \
AREA:r#EACC00:"Runnable" \
STACK:b#9C0000:"Blocked" \
STACK:w#3377DD:"Waiting"


${RRD} graph ${OUTPUTDIR}/${IMAGE_MONTH_MEM} \
--start -2678400 \
--vertical-label "memory" \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:s=${LOGDIR}/${RRDFILE}:swpd:AVERAGE \
DEF:f=${LOGDIR}/${RRDFILE}:free:AVERAGE \
DEF:b=${LOGDIR}/${RRDFILE}:buff:AVERAGE \
DEF:c=${LOGDIR}/${RRDFILE}:cache:AVERAGE \
CDEF:sm=s,1024,* \
CDEF:fm=f,1024,* \
CDEF:bm=b,1024,* \
CDEF:cm=c,1024,* \
AREA:sm#9C0000:"Swapped" \
STACK:cm#EACC00:"Cached" \
STACK:bm#3377DD:"Buffered" \
STACK:fm#00FF00:"Free"


${RRD} graph ${OUTPUTDIR}/${IMAGE_MONTH_SWAP} \
--start -2678400 \
--vertical-label "swap" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:si=${LOGDIR}/${RRDFILE}:si:AVERAGE \
DEF:so=${LOGDIR}/${RRDFILE}:so:AVERAGE \
AREA:si#9C0000:"Swap-In" \
STACK:so#EACC00:"Swap-Out" 


${RRD} graph ${OUTPUTDIR}/${IMAGE_MONTH_IO} \
--start -2678400 \
--vertical-label "io-system" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:bi=${LOGDIR}/${RRDFILE}:bi:AVERAGE \
DEF:bo=${LOGDIR}/${RRDFILE}:bo:AVERAGE \
AREA:bi#9C0000:"Blocks-In" \
STACK:bo#EACC00:"Blocks-Out" 


${RRD} graph ${OUTPUTDIR}/${IMAGE_MONTH_SYS} \
--start -2678400 \
--vertical-label "system" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:int=${LOGDIR}/${RRDFILE}:int:AVERAGE \
DEF:cont=${LOGDIR}/${RRDFILE}:cont:AVERAGE \
AREA:cont#EACC00:"Context-Switches" \
LINE1:int#9C0000:"Interrupts"


${RRD} graph ${OUTPUTDIR}/${IMAGE_MONTH_CPU} \
--start -2678400 \
--vertical-label "cpu in %" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:user=${LOGDIR}/${RRDFILE}:user:AVERAGE \
DEF:sys=${LOGDIR}/${RRDFILE}:sys:AVERAGE \
DEF:idle=${LOGDIR}/${RRDFILE}:idle:AVERAGE \
AREA:user#EACC00:"User" \
STACK:sys#3377DD:"System" \
STACK:idle#00FF00:"Idle"


# YEAR
# ----------------------------------------------------------
${RRD} graph ${OUTPUTDIR}/${IMAGE_YEAR_PROC} \
--start -33053184 \
--vertical-label "processes" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:r=${LOGDIR}/${RRDFILE}:run:AVERAGE \
DEF:b=${LOGDIR}/${RRDFILE}:block:AVERAGE \
DEF:w=${LOGDIR}/${RRDFILE}:wait:AVERAGE \
AREA:r#EACC00:"Runnable" \
STACK:b#9C0000:"Blocked" \
STACK:w#3377DD:"Waiting"


${RRD} graph ${OUTPUTDIR}/${IMAGE_YEAR_MEM} \
--start -33053184 \
--vertical-label "memory" \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:s=${LOGDIR}/${RRDFILE}:swpd:AVERAGE \
DEF:f=${LOGDIR}/${RRDFILE}:free:AVERAGE \
DEF:b=${LOGDIR}/${RRDFILE}:buff:AVERAGE \
DEF:c=${LOGDIR}/${RRDFILE}:cache:AVERAGE \
CDEF:sm=s,1024,* \
CDEF:fm=f,1024,* \
CDEF:bm=b,1024,* \
CDEF:cm=c,1024,* \
AREA:sm#9C0000:"Swapped" \
STACK:cm#EACC00:"Cached" \
STACK:bm#3377DD:"Buffered" \
STACK:fm#00FF00:"Free"


${RRD} graph ${OUTPUTDIR}/${IMAGE_YEAR_SWAP} \
--start -33053184 \
--vertical-label "swap" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:si=${LOGDIR}/${RRDFILE}:si:AVERAGE \
DEF:so=${LOGDIR}/${RRDFILE}:so:AVERAGE \
AREA:si#9C0000:"Swap-In" \
STACK:so#EACC00:"Swap-Out" 


${RRD} graph ${OUTPUTDIR}/${IMAGE_YEAR_IO} \
--start -33053184 \
--vertical-label "io-system" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:bi=${LOGDIR}/${RRDFILE}:bi:AVERAGE \
DEF:bo=${LOGDIR}/${RRDFILE}:bo:AVERAGE \
AREA:bi#9C0000:"Blocks-In" \
STACK:bo#EACC00:"Blocks-Out" 


${RRD} graph ${OUTPUTDIR}/${IMAGE_YEAR_SYS} \
--start -33053184 \
--vertical-label "system" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:int=${LOGDIR}/${RRDFILE}:int:AVERAGE \
DEF:cont=${LOGDIR}/${RRDFILE}:cont:AVERAGE \
AREA:cont#EACC00:"Context-Switches" \
LINE1:int#9C0000:"Interrupts"


${RRD} graph ${OUTPUTDIR}/${IMAGE_YEAR_CPU} \
--start -33053184 \
--vertical-label "cpu in %" \
--units-exponent 0 \
-w ${IMAGE_WIDTH} -h ${IMAGE_HEIGHT} \
DEF:user=${LOGDIR}/${RRDFILE}:user:AVERAGE \
DEF:sys=${LOGDIR}/${RRDFILE}:sys:AVERAGE \
DEF:idle=${LOGDIR}/${RRDFILE}:idle:AVERAGE \
AREA:user#EACC00:"User" \
STACK:sys#3377DD:"System" \
STACK:idle#00FF00:"Idle"




cat<<EOF>${OUTPUTDIR}/${INDEXHTML}
<html>
<head>
<title>vmstat-history</title>
<style type='text/css'>
*{font-family:verdana,arial,helvetica,sans-serif;color:#000;background-color:#fff;}
body,p{text-align:center;}
h1{font-wight:bold;font-size:xx-large;}
h2{font-wight:bold;font-size:x-large;margin-top:1.5em;border:1px solid black; background-color:#eee;padding:0.2em;}
</style>
</head>
<body>
<h1>vmstat-history ${HOST}</h1>
<h2>last 5 hours</h2>
<p>
<img src='./${IMAGE_HOUR_CPU}' alt='cpu'>
</p>
<p>
<img src='./${IMAGE_HOUR_MEM}' alt='memory'>
</p>
<p>
<img src='./${IMAGE_HOUR_SWAP}' alt='swap'>
</p>
<p>
<img src='./${IMAGE_HOUR_IO}' alt='io'>
</p>
<p>
<img src='./${IMAGE_HOUR_PROC}' alt='processes'>
</p>
<p>
<img src='./${IMAGE_HOUR_SYS}' alt='system'>
</p>
<h2>today</h2>
<p>
<img src='./${IMAGE_CPU}' alt='cpu'>
</p>
<p>
<img src='./${IMAGE_MEM}' alt='memory'>
</p>
<p>
<img src='./${IMAGE_SWAP}' alt='swap'>
</p>
<p>
<img src='./${IMAGE_IO}' alt='io'>
</p>
<p>
<img src='./${IMAGE_PROC}' alt='processes'>
</p>
<p>
<img src='./${IMAGE_SYS}' alt='system'>
</p>
<h2>last week</h2>
<p>
<img src='./${IMAGE_WEEK_CPU}' alt='cpu'>
</p>
<p>
<img src='./${IMAGE_WEEK_MEM}' alt='memory'>
</p>
<p>
<img src='./${IMAGE_WEEK_SWAP}' alt='swap'>
</p>
<p>
<img src='./${IMAGE_WEEK_IO}' alt='io'>
</p>
<p>
<img src='./${IMAGE_WEEK_PROC}' alt='processes'>
</p>
<p>
<img src='./${IMAGE_WEEK_SYS}' alt='system'>
</p>
<h2>last month</h2>
<p>
<img src='./${IMAGE_MONTH_CPU}' alt='cpu'>
</p>
<p>
<img src='./${IMAGE_MONTH_MEM}' alt='memory'>
</p>
<p>
<img src='./${IMAGE_MONTH_SWAP}' alt='swap'>
</p>
<p>
<img src='./${IMAGE_MONTH_IO}' alt='io'>
</p>
<p>
<img src='./${IMAGE_MONTH_PROC}' alt='processes'>
</p>
<p>
<img src='./${IMAGE_MONTH_SYS}' alt='system'>
</p>
<h2>last year</h2>
<p>
<img src='./${IMAGE_YEAR_CPU}' alt='cpu'>
</p>
<p>
<img src='./${IMAGE_YEAR_MEM}' alt='memory'>
</p>
<p>
<img src='./${IMAGE_YEAR_SWAP}' alt='swap'>
</p>
<p>
<img src='./${IMAGE_YEAR_IO}' alt='io'>
</p>
<p>
<img src='./${IMAGE_YEAR_PROC}' alt='processes'>
</p>
<p>
<img src='./${IMAGE_YEAR_SYS}' alt='system'>
</p>
</body>
</html>
EOF




